@@ -1,7 +1,7 @@
 
 #*******************************************************************************
 # fExtremes - A SOFTWARE COLLECTION FOR FINANCIAL ENGINEERS
-# PART III: Beyond the Sample: Dealing with Extreme Values
+# Beyond the Sample: Dealing with Extreme Values
 #
 # collected by Diethelm Wuertz
 # Version 0.9
@@ -25,7 +25,7 @@
 
 # Copyrights (C)
 # for this R-port: 
-#   1999 - 2004, Diethelm Wuertz, GPL
+#   1999 - 2007, Diethelm Wuertz, GPL
 #   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
 #   info@rmetrics.org
 #   www.rmetrics.org
@@ -41,15 +41,15 @@
 
 .First.lib = 
 function(lib, pkg)
-{ 	# A function implemted by D. Wuertz
+{   # A function implemted by Diethelm Wuertz
 
-	# Package:
-	cat("\nRmetrics, (C) 1999-2004, Diethelm Wuertz, GPL")
-	cat("\nfExtremes: Beyond the Sample: Dealing with Extreme Values\n")
-	
-	# Load dll:
-	# library.dynam("fExtremes", pkg, lib)
-	
+    # Package:
+    cat("\nRmetrics, (C) 1999-2004, Diethelm Wuertz, GPL")
+    cat("\nfExtremes: Beyond the Sample: Dealing with Extreme Values\n")
+    
+    # Load dll:
+    # library.dynam("fExtremes", pkg, lib)
+    
 }
 
 
